.. :changelog:

History
-------

0.2.0 (2017-09-25)
++++++++++++++++++

* History and tooling scripts
* Functioning API with Sanic server
* Versioning tools

0.1.0 (2017-09-24)
++++++++++++++++++

* First release on PyPI.
